@@ -12,9 +12,10 @@ class PipelineWorkflowMixin(object):
 
         :param project_id: id of the project within tenant
         :param omit_steps: whether to omit steps in the response for better
-            performance
-        :param omit_sources: whether to omit in the response the data sources which are
-        configured to use each pipeline workflow
+                           performance.
+        :param omit_sources: whether to omit in the response the data sources
+                             which are configured to use each pipeline
+                             workflow.
         :return: A list of pipeline workflow dictionaries.
 
         Example::
@@ -63,15 +64,14 @@ class PipelineWorkflowMixin(object):
     def get_pipeline_workflow(
         self, project_id, workflow_id, omit_steps=False, omit_sources=False
     ):
-        """Return a specific pipeline workflow `workflow_id` in project with
-        `project_id`.
+        """Return a specific pipeline workflow `workflow_id` in project with `project_id`.
 
         :param project_id: project id
         :param workflow_id: pipeline workflow id
         :param omit_steps: whether to omit steps in the response for better
-            performance
+                           performance.
         :param omit_sources: whether to omit in the response the data sources which are
-        configured to use this pipeline workflow
+                             configured to use this pipeline workflow.
         :return: A dictionary of the pipeline workflow.
 
         Example::
@@ -117,7 +117,7 @@ class PipelineWorkflowMixin(object):
         return self._process_response(res)
 
     def new_pipeline_workflow(self, project_id, name, steps=None):
-        """Creates a new pipeline workflow
+        """Creates a new pipeline workflow.
 
         :param project_id: project id
         :param name: name of workflow
@@ -289,7 +289,7 @@ class PipelineWorkflowMixin(object):
 
         :param project_id: the Id of the project
         :return: a list of dictionaries where each dictionary represents a pipeline
-        workflow preset.
+                 workflow preset.
         """
         headers = {"Accept": "application/json"}
 
@@ -305,3 +305,30 @@ class PipelineWorkflowMixin(object):
         res = self._perform_request("get", url, headers=headers)
 
         return self._process_response(res)
+
+    def rerun_pipeline_workflow(self, project_id, workflow_id, from_index=False):
+        """Rerun a pipeline workflow using the data of its configured data sources.
+
+        :param project_id: the Id of the project that this workflow belongs to.
+        :param workflow_id: the Id of the pipeline workflow to rerun.
+        :param from_index: if True then this flag indicates that rerun will use the
+            indexed Squirro items as input to the workflow for ingestion.
+        """
+        headers = {"Accept": "application/json"}
+
+        params = {"from_index": from_index}
+
+        url = (
+            "%(ep)s/v0/%(tenant)s/projects/%(project_id)s/"
+            "pipeline_workflows/%(workflow_id)s/rerun"
+            % {
+                "ep": self.topic_api_url,
+                "tenant": self.tenant,
+                "project_id": project_id,
+                "workflow_id": workflow_id,
+            }
+        )
+
+        res = self._perform_request("post", url, params=params, headers=headers)
+
+        return self._process_response(res)
