@@ -34,6 +34,7 @@ class SourcesMixin(object):
                 "items_fetched_total": 2,
                 "last_error": "",
                 "last_check_at": "2019-01-23T10:23:23",
+                "last_items_at": "2019-01-23T10:23:23",
                 "paused": false,
                 "error_count": 0,
                 "id": "pqTn4vBZRdS5hYw0TBt0pQ",
@@ -123,6 +124,7 @@ class SourcesMixin(object):
               "items_fetched_total": 2,
               "last_error": "",
               "last_check_at": "2019-01-23T10:23:23",
+              "last_items_at": "2019-01-23T10:23:23",
               "paused": false,
               "error_count": 0,
               "id": "pqTn4vBZRdS5hYw0TBt0pQ",
@@ -193,6 +195,7 @@ class SourcesMixin(object):
         source_id=None,
         paused=False,
         use_default_options=None,
+        notify_scheduler=None,
     ):
         """Create a new source.
 
@@ -216,6 +219,9 @@ class SourcesMixin(object):
             workflow provided by the dataloader plugin itself.
             Setting this to `True` will throw a 400 HTTP error code if these default
             mappings are not available for a specific plugin
+        :param notify_scheduler: Optional boolean. Indicate whether or not to notify
+            the scheduler to immediately start the procedure of loading data from the
+            source.
         :returns: A dictionary which contains the new source.
 
         Example::
@@ -239,6 +245,7 @@ class SourcesMixin(object):
               "items_fetched_total": 0,
               "last_error": "",
               "last_check_at": null,
+              "last_items_at": null,
               "paused": false,
               "error_count": 0,
               "id": "601AoqmkSFWGt4sAwaX8ag",
@@ -282,6 +289,8 @@ class SourcesMixin(object):
             data["scheduling_options"] = scheduling_options
         if use_default_options is not None:
             data["use_default_options"] = use_default_options
+        if notify_scheduler is not None:
+            data["notify_scheduler"] = notify_scheduler
 
         res = self._perform_request("post", url, data=json.dumps(data), headers=headers)
         return self._process_response(res, [200, 201])
@@ -296,14 +305,28 @@ class SourcesMixin(object):
         pipeline_workflow_id=None,
         enable_scheduling=None,
         validate_schema=None,
+        notify_scheduler=None,
+        execute_rerun=None,
     ):
         """Modify an existing source.
 
         :param project_id: Project identifier.
         :param source_id: Source identifier.
+        :param name: Name for the Source.
+        :param config: Changed config of the source.
+        :param scheduling_options: dict, scheduling options for the run of a
+            Source.
         :param pipeline_workflow_id: Optional pipeline workflow id to change
             the source to.
-        :param config: Changed config of the source.
+        :param enable_scheduling: Optional boolean. Indicate whether or not to enable the
+            scheduling of this source.
+        :param validate_schema: Optional boolean. Indicate whether or not to validate the
+            provided configuration of the source.
+        :param notify_scheduler: Optional boolean. Indicate whether or not to notify
+            the scheduler to immediately start the procedure of loading data from the
+            source.
+        :param execute_rerun: Optional boolean. Indicate whether or not to queue for
+            reprocessing the batches (if any) of this source.
 
         :returns: A dictionary which contains the source.
 
@@ -359,6 +382,10 @@ class SourcesMixin(object):
             data["enable_scheduling"] = enable_scheduling
         if validate_schema is not None:
             data["validate_schema"] = validate_schema
+        if notify_scheduler is not None:
+            data["notify_scheduler"] = notify_scheduler
+        if execute_rerun is not None:
+            data["execute_rerun"] = execute_rerun
 
         res = self._perform_request("put", url, data=json.dumps(data), headers=headers)
         return self._process_response(res, [200])
